@@ -150,7 +150,7 @@ THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 /* Set structure elements aligment on bytes
  * http://gcc.gnu.org/onlinedocs/gcc/Structure_002dPacking-Pragmas.html */
-#if defined(__APPLE__) | defined(sun)
+#if defined(__APPLE__) || defined(sun) || defined(__NetBSD__)
 #pragma pack(1)
 #else
 #pragma pack(push, 1)
@@ -247,7 +247,7 @@ typedef struct {
 } PIN_PROPERTIES_STRUCTURE;
 
 /* restore default structure elements alignment */
-#if defined(__APPLE__) | defined(sun)
+#if defined(__APPLE__) || defined(sun) || defined(__NetBSD__)
 #pragma pack()
 #else
 #pragma pack(pop)
